==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Transports/http/translations/http_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="33"/>
        <source>HTTP Plugin</source>
        <translation>Plugin HTTP</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="53"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Tentang Plugin Transport HTTP</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>Plugin Transport HTTP Qmmp</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Compiled against libcurl-%1</source>
        <translation>Dikompilasi terhadap libcurl-%1</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>Setelan Plugin HTTP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Ukuran buffer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metadata pengkodean</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Deteksi charset otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Bahasa:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Pengkodean baku:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <source>User Agent:</source>
        <translation>Agen Pengguna:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Change User Agent</source>
        <translation>Ubah Pengguna Agen</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Transports/http/translations/http_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="34"/>
        <source>HTTP Plugin</source>
        <translation>Plugin HTTP</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Tentang Plugin Transport HTTP</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>Plugin Transport HTTP Qmmp</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Compiled against libcurl-%1</source>
        <translation>Dikompilasi terhadap libcurl-%1</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>Setelan Plugin HTTP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Ukuran buffer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metadata pengkodean</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Deteksi charset otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Bahasa:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Pengkodean baku:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <source>User Agent:</source>
        <translation>Agen Pengguna:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Change User Agent</source>
        <translation>Ubah Pengguna Agen</translation>
    </message>
</context>
</TS>
